#######################
Resource Manager
#######################

The :code:`list_resources` function provides an interface to check connected instruments interactively.

.. autofunction:: pymeasure.instruments.list_resources
